@@ -166,6 +166,7 @@ class Connection(object):
         if ssl and (ssl.has_key('capath') or ssl.has_key('cipher')):
             raise NotImplementedError('ssl options capath and cipher are not supported')
 
+        self.sock = None
         self.ssl = False
         if ssl:
             self.ssl = True
@@ -319,6 +320,9 @@ class Connection(object):
             self.socket.close()
             self.socket = None
 
+    def _is_connect(self):
+        return bool(self.sock)
+
     # The following methods are INTERNAL USE ONLY (called from Cursor)
     def query(self, sql):
         if DEBUG:
