@@ -225,7 +225,12 @@ class TestNewIssues(base.PyMySQLTestCase):
                 kill_id = id
                 break
         # now nuke the connection
-        conn.kill(kill_id)
+        try:
+            conn.kill(kill_id)
+        except cymysql.InternalError:   # MySQL 5.6
+            exc,value,tb = sys.exc_info()
+            self.assertEqual(value[0], 1317)
+            self.assertEqual(value[1], 'Query execution was interrupted')
         # make sure this connection has broken
         try:
             c.execute("show tables")
